@@ -1,15 +1,6 @@
 from __future__ import annotations
 
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Iterable,
-    Iterator,
-    Mapping,
-    Sequence,
-    cast,
-    overload,
-)
+from typing import TYPE_CHECKING, Any, cast, overload
 
 import pyarrow as pa
 import pyarrow.compute as pc
@@ -32,18 +23,18 @@ from narwhals._arrow.utils import (
 )
 from narwhals._compliant import EagerSeries
 from narwhals._expression_parsing import ExprKind
+from narwhals._typing_compat import assert_never
 from narwhals._utils import (
     Implementation,
     generate_temporary_column_name,
     is_list_of,
     not_implemented,
-    requires,
-    validate_backend_version,
 )
 from narwhals.dependencies import is_numpy_array_1d
-from narwhals.exceptions import InvalidOperationError
+from narwhals.exceptions import InvalidOperationError, ShapeError
 
 if TYPE_CHECKING:
+    from collections.abc import Iterable, Iterator, Mapping, Sequence
     from types import ModuleType
 
     import pandas as pd
@@ -64,7 +55,7 @@ if TYPE_CHECKING:
         _AsPyType,
         _BasicDataType,
     )
-    from narwhals._utils import Version, _FullContext
+    from narwhals._utils import Version, _LimitedContext
     from narwhals.dtypes import DType
     from narwhals.typing import (
         ClosedInterval,
@@ -123,20 +114,14 @@ def maybe_extract_py_scalar(value: Any, return_py_scalar: bool) -> Any:  # noqa:
 
 
 class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
+    _implementation = Implementation.PYARROW
+
     def __init__(
-        self,
-        native_series: ChunkedArrayAny,
-        *,
-        name: str,
-        backend_version: tuple[int, ...],
-        version: Version,
+        self, native_series: ChunkedArrayAny, *, name: str, version: Version
     ) -> None:
         self._name = name
         self._native_series: ChunkedArrayAny = native_series
-        self._implementation = Implementation.PYARROW
-        self._backend_version = backend_version
         self._version = version
-        validate_backend_version(self._implementation, self._backend_version)
         self._broadcast = False
 
     @property
@@ -144,12 +129,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         return self._native_series
 
     def _with_version(self, version: Version) -> Self:
-        return self.__class__(
-            self.native,
-            name=self._name,
-            backend_version=self._backend_version,
-            version=version,
-        )
+        return self.__class__(self.native, name=self._name, version=version)
 
     def _with_native(
         self, series: ArrayOrScalar, *, preserve_broadcast: bool = False
@@ -164,7 +144,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         cls,
         data: Iterable[Any],
         *,
-        context: _FullContext,
+        context: _LimitedContext,
         name: str = "",
         dtype: IntoDType | None = None,
     ) -> Self:
@@ -175,7 +155,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         )
 
     def _from_scalar(self, value: Any) -> Self:
-        if self._backend_version < (13,) and hasattr(value, "as_py"):
+        if hasattr(value, "as_py"):
             value = value.as_py()
         return super()._from_scalar(value)
 
@@ -185,27 +165,39 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
 
     @classmethod
     def from_native(
-        cls, data: ChunkedArrayAny, /, *, context: _FullContext, name: str = ""
+        cls, data: ChunkedArrayAny, /, *, context: _LimitedContext, name: str = ""
     ) -> Self:
-        return cls(
-            data,
-            backend_version=context._backend_version,
-            version=context._version,
-            name=name,
-        )
+        return cls(data, version=context._version, name=name)
 
     @classmethod
-    def from_numpy(cls, data: Into1DArray, /, *, context: _FullContext) -> Self:
+    def from_numpy(cls, data: Into1DArray, /, *, context: _LimitedContext) -> Self:
         return cls.from_iterable(
             data if is_numpy_array_1d(data) else [data], context=context
         )
 
+    @classmethod
+    def _align_full_broadcast(cls, *series: Self) -> Sequence[Self]:
+        lengths = [len(s) for s in series]
+        max_length = max(lengths)
+        fast_path = all(_len == max_length for _len in lengths)
+        if fast_path:
+            return series
+        reshaped = []
+        for s in series:
+            if s._broadcast:
+                compliant = s._with_native(pa.repeat(s.native[0], max_length))
+            elif (actual_len := len(s)) != max_length:
+                msg = f"Expected object of length {max_length}, got {actual_len}."
+                raise ShapeError(msg)
+            else:
+                compliant = s
+            reshaped.append(compliant)
+        return reshaped
+
     def __narwhals_namespace__(self) -> ArrowNamespace:
         from narwhals._arrow.namespace import ArrowNamespace
 
-        return ArrowNamespace(
-            backend_version=self._backend_version, version=self._version
-        )
+        return ArrowNamespace(version=self._version)
 
     def __eq__(self, other: object) -> Self:  # type: ignore[override]
         other = cast("PythonLiteral | ArrowSeries | None", other)
@@ -394,6 +386,19 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
             biased_population_skewness = pc.divide(m3, pc.power(m2, lit(1.5)))
             return maybe_extract_py_scalar(biased_population_skewness, _return_py_scalar)
 
+    def kurtosis(self, *, _return_py_scalar: bool = True) -> float | None:
+        ser_not_null = self.native.drop_null()
+        if len(ser_not_null) == 0:
+            return None
+        elif len(ser_not_null) == 1:
+            return float("nan")
+        else:
+            m = pc.subtract(ser_not_null, pc.mean(ser_not_null))
+            m2 = pc.mean(pc.power(m, lit(2)))
+            m4 = pc.mean(pc.power(m, lit(4)))
+            k = pc.subtract(pc.divide(m4, pc.power(m2, lit(2))), lit(3))
+            return maybe_extract_py_scalar(k, _return_py_scalar)
+
     def count(self, *, _return_py_scalar: bool = True) -> int:
         return maybe_extract_py_scalar(pc.count(self.native), _return_py_scalar)
 
@@ -462,9 +467,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         # - Missing `replacements` type
         # - Missing return type
         pc_replace_with_mask: Incomplete = pc.replace_with_mask
-        return self._with_native(
-            pc_replace_with_mask(self.native, mask, values_native.take(indices_native))
-        )
+        return self._with_native(pc_replace_with_mask(self.native, mask, values_native))
 
     def to_list(self) -> list[Any]:
         return self.native.to_pylist()
@@ -476,12 +479,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         return self.native.to_numpy()
 
     def alias(self, name: str) -> Self:
-        result = self.__class__(
-            self.native,
-            name=name,
-            backend_version=self._backend_version,
-            version=self._version,
-        )
+        result = self.__class__(self.native, name=name, version=self._version)
         result._broadcast = self._broadcast
         return result
 
@@ -540,8 +538,8 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
             ge = pc.greater_equal(self.native, lower_bound)
             le = pc.less_equal(self.native, upper_bound)
             res = pc.and_kleene(ge, le)
-        else:  # pragma: no cover
-            raise AssertionError
+        else:
+            assert_never(closed)
         return self._with_native(res)
 
     def is_null(self) -> Self:
@@ -619,10 +617,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
             val_count = val_count.sort_by([(value_name_, "descending")])
 
         return ArrowDataFrame(
-            val_count,
-            backend_version=self._backend_version,
-            version=self._version,
-            validate_column_names=True,
+            val_count, version=self._version, validate_column_names=True
         )
 
     def zip_with(self, mask: Self, other: Self) -> Self:
@@ -644,7 +639,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
             n = int(num_rows * fraction)
 
         rng = np.random.default_rng(seed=seed)
-        idx = np.arange(0, num_rows)
+        idx = np.arange(num_rows)
         mask = rng.choice(idx, size=n, replace=with_replacement)
         return self._with_native(self.native.take(mask))
 
@@ -694,12 +689,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         from narwhals._arrow.dataframe import ArrowDataFrame
 
         df = pa.Table.from_arrays([self.native], names=[self.name])
-        return ArrowDataFrame(
-            df,
-            backend_version=self._backend_version,
-            version=self._version,
-            validate_column_names=False,
-        )
+        return ArrowDataFrame(df, version=self._version, validate_column_names=False)
 
     def to_pandas(self) -> pd.Series[Any]:
         import pandas as pd  # ignore-banned-import()
@@ -817,7 +807,6 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         )
         return ArrowDataFrame(
             pa.Table.from_arrays(columns, names=cols),
-            backend_version=self._backend_version,
             version=self._version,
             validate_column_names=True,
         ).simple_select(*output_order)
@@ -874,7 +863,6 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         dtypes = self._version.dtypes
         return (~self.is_null()).cast(dtypes.UInt32()).cum_sum(reverse=reverse)
 
-    @requires.backend_version((13,))
     def cum_min(self, *, reverse: bool) -> Self:
         result = (
             pc.cumulative_min(self.native, skip_nulls=True)
@@ -883,7 +871,6 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         )
         return self._with_native(result)
 
-    @requires.backend_version((13,))
     def cum_max(self, *, reverse: bool) -> Self:
         result = (
             pc.cumulative_max(self.native, skip_nulls=True)
@@ -892,7 +879,6 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         )
         return self._with_native(result)
 
-    @requires.backend_version((13,))
     def cum_prod(self, *, reverse: bool) -> Self:
         result = (
             pc.cumulative_prod(self.native, skip_nulls=True)
@@ -1028,10 +1014,9 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
 
         rank = pc.rank(native_series, sort_keys=sort_keys, tiebreaker=tiebreaker)
 
-        result = pc.if_else(null_mask, lit(None, native_series.type), rank)
+        result = pc.if_else(null_mask, lit(None, rank.type), rank)
         return self._with_native(result)
 
-    @requires.backend_version((13,))
     def hist(  # noqa: C901, PLR0912, PLR0915
         self,
         bins: list[float | int] | None,
@@ -1126,10 +1111,7 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
         data["count"] = counts
 
         return ArrowDataFrame(
-            pa.Table.from_pydict(data),
-            backend_version=self._backend_version,
-            version=self._version,
-            validate_column_names=True,
+            pa.Table.from_pydict(data), version=self._version, validate_column_names=True
         )
 
     def __iter__(self) -> Iterator[Any]:
@@ -1160,6 +1142,9 @@ class ArrowSeries(EagerSeries["ChunkedArrayAny"]):
     def exp(self) -> Self:
         return self._with_native(pc.exp(self.native))
 
+    def sqrt(self) -> Self:
+        return self._with_native(pc.sqrt(self.native))
+
     @property
     def dt(self) -> ArrowSeriesDateTimeNamespace:
         return ArrowSeriesDateTimeNamespace(self)
